@@ -370,8 +370,8 @@ class Session(object):
         # Possibly create tarballs out of required python packages
         self.handle_python_package_tarballs(cluster)
         # Possibly create tarball for the seutils cache and include it in the job
-        if seutils.USE_CACHE:
-            cluster.transfer_files["seutils-cache"] = self.dump_seutils_cache()
+        # if seutils.USE_CACHE:
+        #     cluster.transfer_files["seutils-cache"] = self.dump_seutils_cache()
         # Dump cluster contents to file and build scope
         cluster.runcode_to_file()
         cluster.sh_entrypoint_to_file()
@@ -395,7 +395,7 @@ class Session(object):
         sub.update(cluster.htcondor)
         # Flatten files into a string, excluding files on storage elements
         transfer_files = self.transfer_files + [
-            f for f in cluster.transfer_files.values() if not seutils.has_protocol(f)
+            f for f in cluster.transfer_files.values() if not seutils.path.has_protocol(f)
         ]
         if len(transfer_files) > 0:
             sub["transfer_input_files"] = ",".join(transfer_files)
@@ -578,7 +578,8 @@ class Session(object):
         # Clear the submittables
         self.submittables = []
         self.submitted = []
-        return submission
+        if not qondor.DRYMODE:
+            return submission
 
 
 class Cluster(object):
@@ -616,7 +617,7 @@ class Cluster(object):
                 # Conda pack mode
                 conda_tarball = run_env.replace("condapack:", "", 1)
                 self.run_env = []
-                if seutils.has_protocol(conda_tarball):
+                if seutils.path.has_protocol(conda_tarball):
                     self.run_env.append("xrdcp {0} .".format(conda_tarball))
                 else:
                     raise NotImplementedError(
@@ -802,7 +803,7 @@ class Cluster(object):
         if self._is_conda_pack:
             pip_install_options = "--no-cache-dir --no-use-pep517"
         else:
-            pip_install_options = '--install-option="--prefix=${{pip_install_dir}}" --no-cache-dir --no-use-pep517'
+            pip_install_options = '--install-option="--prefix=${pip_install_dir}" --no-cache-dir --no-use-pep517'
 
         # `pip install` the required pip packages for the job
         for package, install_instruction in self.pips:
